pub unsafe fn lean_closure_get(o: b_lean_obj_arg, i: u32) -> *mut lean_objectExpand description
Read the i-th captured argument (lean.h:778).
Safety
o must be a borrowed Lean closure object and i < num_fixed(o).
pub unsafe fn lean_closure_get(o: b_lean_obj_arg, i: u32) -> *mut lean_objectRead the i-th captured argument (lean.h:778).
o must be a borrowed Lean closure object and i < num_fixed(o).