lean_unbox_float

Function lean_unbox_float 

pub unsafe fn lean_unbox_float(o: b_lean_obj_arg) -> f64
Recover the f64 payload from a constructor produced by lean_box_float (lean.h:2861–2863).

Safety

o must be a borrowed constructor object produced by lean_box_float (or by Lean’s compiler in a polymorphic position holding a Float).