lean_internal_set_max_memory

Function lean_internal_set_max_memory 

pub unsafe extern "C" fn lean_internal_set_max_memory(
    max: usize,
) -> lean_obj_res
Set Lean’s process-global maximum memory in bytes.

Safety

This changes process-global Lean runtime state. Callers must ensure they are configuring an isolated worker/profiling process or otherwise understand that every later Lean runtime check in the process observes the new limit.