lean_alloc_object

Function lean_alloc_object 

pub unsafe extern "C" fn lean_alloc_object(
    sz: usize,
) -> *mut lean_object
Allocate an uninitialized Lean heap object of size sz bytes (lean.h:490). The caller is responsible for initializing the header via lean_set_st_header-equivalent writes, which only this crate’s helpers should perform.