pub unsafe extern "C" fn lean_mark_persistent(o: *mut lean_object)Expand description
Mark a heap object as persistent so its refcount is no longer
updated (lean.h:613).
pub unsafe extern "C" fn lean_mark_persistent(o: *mut lean_object)Mark a heap object as persistent so its refcount is no longer
updated (lean.h:613).