lean_string_cstr

Function lean_string_cstr 

pub unsafe fn lean_string_cstr(o: b_lean_obj_arg) -> *const c_char
Pointer to the string’s NUL-terminated UTF-8 bytes (lean.h:1178–1181).

Safety

o must be a borrowed Lean string object. The returned pointer is valid for as long as o retains the refcount that the caller borrowed.